kedro.extras — Kedro 0.17.6 documentation

# kedro.extras

Description

`kedro.extras` provides functionality such as datasets and extensions.

Modules

`kedro.extras.datasets` | `kedro.extras.datasets` is where you can find all of Kedro’s data connectors.
`kedro.extras.decorators` | `kedro.extras.decorators` provides Node/Pipeline Decorators.
`kedro.extras.extensions` | This module contains an IPython extension.
`kedro.extras.logging` | This module contains a logging handler class which produces coloured logs.
`kedro.extras.transformers` | `kedro.extras.transformers` is the home of Kedro’s dataset transformers.